Class: PricingPlans::PriceComponents

Inherits:
Struct
  • Object
show all
Defined in:
lib/pricing_plans/price_components.rb

Overview

Pure-data value object describing a plan price in semantic parts. UI-agnostic. Useful to render classic pricing typography and power JS toggles.

Instance Attribute Summary collapse

Instance Attribute Details

#amountObject

Returns the value of attribute amount

Returns:

  • (Object)

    the current value of amount



6
7
8
# File 'lib/pricing_plans/price_components.rb', line 6

def amount
  @amount
end

#amount_centsObject

Returns the value of attribute amount_cents

Returns:

  • (Object)

    the current value of amount_cents



6
7
8
# File 'lib/pricing_plans/price_components.rb', line 6

def amount_cents
  @amount_cents
end

#currencyObject

Returns the value of attribute currency

Returns:

  • (Object)

    the current value of currency



6
7
8
# File 'lib/pricing_plans/price_components.rb', line 6

def currency
  @currency
end

#intervalObject

Returns the value of attribute interval

Returns:

  • (Object)

    the current value of interval



6
7
8
# File 'lib/pricing_plans/price_components.rb', line 6

def interval
  @interval
end

#labelObject

Returns the value of attribute label

Returns:

  • (Object)

    the current value of label



6
7
8
# File 'lib/pricing_plans/price_components.rb', line 6

def label
  @label
end

#monthly_equivalent_centsObject

Returns the value of attribute monthly_equivalent_cents

Returns:

  • (Object)

    the current value of monthly_equivalent_cents



6
7
8
# File 'lib/pricing_plans/price_components.rb', line 6

def monthly_equivalent_cents
  @monthly_equivalent_cents
end

#present?Object

Returns the value of attribute present?

Returns:

  • (Object)

    the current value of present?



6
7
8
# File 'lib/pricing_plans/price_components.rb', line 6

def present?
  @present?
end