Class: PricingPlans::PriceComponents
- Inherits:
-
Struct
- Object
- Struct
- PricingPlans::PriceComponents
- Defined in:
- lib/pricing_plans/price_components.rb
Overview
Pure-data value object describing a plan price in semantic parts. UI-agnostic. Useful to render classic pricing typography and power JS toggles.
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#amount_cents ⇒ Object
Returns the value of attribute amount_cents.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#interval ⇒ Object
Returns the value of attribute interval.
-
#label ⇒ Object
Returns the value of attribute label.
-
#monthly_equivalent_cents ⇒ Object
Returns the value of attribute monthly_equivalent_cents.
-
#present? ⇒ Object
Returns the value of attribute present?.
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount
6 7 8 |
# File 'lib/pricing_plans/price_components.rb', line 6 def amount @amount end |
#amount_cents ⇒ Object
Returns the value of attribute amount_cents
6 7 8 |
# File 'lib/pricing_plans/price_components.rb', line 6 def amount_cents @amount_cents end |
#currency ⇒ Object
Returns the value of attribute currency
6 7 8 |
# File 'lib/pricing_plans/price_components.rb', line 6 def currency @currency end |
#interval ⇒ Object
Returns the value of attribute interval
6 7 8 |
# File 'lib/pricing_plans/price_components.rb', line 6 def interval @interval end |
#label ⇒ Object
Returns the value of attribute label
6 7 8 |
# File 'lib/pricing_plans/price_components.rb', line 6 def label @label end |
#monthly_equivalent_cents ⇒ Object
Returns the value of attribute monthly_equivalent_cents
6 7 8 |
# File 'lib/pricing_plans/price_components.rb', line 6 def monthly_equivalent_cents @monthly_equivalent_cents end |
#present? ⇒ Object
Returns the value of attribute present?
6 7 8 |
# File 'lib/pricing_plans/price_components.rb', line 6
def present?
@present?
end
|